@@ -122,11 +122,6 @@ pub fn get_all_readouts<'a>(
     let mut readout_values = Vec::with_capacity(ReadoutKey::variants().len());
     let general_readout = GeneralReadout::new();
 
-    let mut tts = false;
-    if cfg!(feature = "tts") {
-        tts = true;
-    }
-
     if should_display.contains(&ReadoutKey::Host) {
         match (general_readout.username(), general_readout.hostname()) {
             (Ok(u), Ok(h)) => {
@@ -295,8 +290,8 @@ pub fn get_all_readouts<'a>(
     }
 
     if should_display.contains(&ReadoutKey::ProcessorLoad) {
-        match (general_readout.cpu_usage(), opt.bar, tts) {
-            (Ok(u), true, false) => {
+        match (general_readout.cpu_usage(), opt.bar) {
+            (Ok(u), true) => {
                 if u > 100 {
                     readout_values.push(Readout::new(
                         ReadoutKey::ProcessorLoad,
@@ -308,10 +303,10 @@ pub fn get_all_readouts<'a>(
                     create_bar(theme, crate::bars::num_to_blocks(u as u8)),
                 ))
             }
-            (Ok(u), _, _) => {
+            (Ok(u), _) => {
                 readout_values.push(Readout::new(ReadoutKey::ProcessorLoad, format_cpu_usage(u)))
             }
-            (Err(e), _, _) => readout_values.push(Readout::new_err(ReadoutKey::ProcessorLoad, e)),
+            (Err(e), _) => readout_values.push(Readout::new_err(ReadoutKey::ProcessorLoad, e)),
         }
     }
 
@@ -325,7 +320,7 @@ pub fn get_all_readouts<'a>(
 
         match (total, used) {
             (Ok(total), Ok(used)) => {
-                if opt.bar && !tts {
+                if opt.bar {
                     let bar = create_bar(theme, crate::bars::memory(used, total));
                     readout_values.push(Readout::new(ReadoutKey::Memory, bar))
                 } else {
@@ -350,7 +345,7 @@ pub fn get_all_readouts<'a>(
 
         match (percentage, state) {
             (Ok(p), Ok(s)) => {
-                if opt.bar && !tts {
+                if opt.bar {
                     let bar = create_bar(theme, crate::bars::num_to_blocks(p));
                     readout_values.push(Readout::new(key, bar));
                 } else {
